Index: trunk/psModules/src/camera/pmFPAfileDefine.h
===================================================================
--- trunk/psModules/src/camera/pmFPAfileDefine.h	(revision 14647)
+++ trunk/psModules/src/camera/pmFPAfileDefine.h	(revision 14889)
@@ -4,6 +4,6 @@
  * @author EAM, IfA
  *
- * @version $Revision: 1.14 $ $Name: not supported by cvs2svn $
- * @date $Date: 2007-08-23 23:42:41 $
+ * @version $Revision: 1.15 $ $Name: not supported by cvs2svn $
+ * @date $Date: 2007-09-19 21:37:58 $
  * Copyright 2004-2005 Institute for Astronomy, University of Hawaii
  */
@@ -28,13 +28,20 @@
 // Define an output pmFPAfile
 pmFPAfile *pmFPAfileDefineOutput(const pmConfig *config, // Configuration
-				 pmFPA *fpa, // Optional FPA to bind
-				 const char *name // Name of camera format to use
+                                 pmFPA *fpa, // Optional FPA to bind
+                                 const char *name // Name of file rule
     );
 
+/// Same as pmFPAfileDefineOutput, but binds to the fpa in the provided file
+pmFPAfile *pmFPAfileDefineOutputFromFile(const pmConfig *config, // Configuration
+                                         pmFPAfile *file, // File to bind FPAs, or NULL
+                                         const char *name // Name of file rule
+    );
+
+/// Define the FPA file using the provided camera and format names.
 pmFPAfile *pmFPAfileDefineOutputForFormat(const pmConfig *config, // Configuration
-					  pmFPA *fpa, // Optional FPA to bind
-					  const char *name, // Name of file rule
-					  const char *cameraName, // Name of camera configuration to use
-					  const char *formatName // Name of camera format to use
+                                          pmFPA *fpa, // Optional FPA to bind
+                                          const char *name, // Name of file rule
+                                          psString cameraName, // Name of camera configuration to use
+                                          psString formatName // Name of camera format to use
     );
 
@@ -69,4 +76,12 @@
 // reference count is held by the config->files metadata.
 pmFPAfile *pmFPAfileDefineFromFPA (const pmConfig *config, pmFPA *src, int xBin, int yBin, const char *filename);
+
+/// Same as pmFPAfileDefineFromFPA, except it uses an FPA file instead of an FPA
+pmFPAfile *pmFPAfileDefineFromFile(const pmConfig *config, // Configuration
+                                   pmFPAfile *src, // Source file for this file
+                                   int xBin, int yBin, // Binning for this file
+                                   const char *filename // Name of file rule
+    );
+
 
 // create a new output pmFPAfile based on an existing FPA
